0.2.36 (2024-07-07)
-------------------

Bugfixes and new subtitle field for blog and podcast.

- #140 Fixed the `page_ptr` stuff again. This time for real.
- #157 Fixed the `get_prep_value` getting called with weird values again. This time for real.
- #134 Added subtitle to blog / podcast
- #136 Added some more documentation for `cover_image` and `cover_image_alt`
- #158 Fixed a no reverse match error when trying to render the podlove player during preview
